//
// Title:   AffineRegistrationDialogImpl.cpp
// Created: March 1, 2003
// Authors: Daniel Cotting, Oliver Knoll, Mark Pauly, Matthias Zwicker
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#include <qcombobox.h>
#include <qspinbox.h>
#include <qlabel.h>
#include <qradiobutton.h>
#include <qpushbutton.h>
#if QT_VERSION >= 0x030000
# include <qptrlist.h>
# ifndef QList
#  define QList QPtrList
# endif
# ifndef QListIterator
#  define QListIterator QPtrListIterator
# endif
#else
# include <qlist.h>
#endif
#include <qstring.h>
#include <qlineedit.h>
#include <qcheckbox.h>
#include <qapplication.h>

#include "../../../../Core/Brush/src/Brush.h"
#include "../../../../Core/CoreResourceTools/src/CoreResourceTools.h"
#include "../../../../Core/CoreResourceTools/BitmapResourceTool/src/BitmapResourceTool.h"
#include "../../../../Core/CoreTools/src/CoreTools.h"

#include "AffineRegistrationTool.h"
#include "AffineRegistrationDialogImpl.h"

// ******
// global
// ******

// the single AffineRegistrationDialogImpl instance, only
// accesible by getInstance() and
// destroyInstance()
static AffineRegistrationDialogImpl *instance = 0;

// *******************
// private c'tor/d'tor
// *******************

AffineRegistrationDialogImpl::AffineRegistrationDialogImpl (AffineRegistrationTool *affineRegistrationTool,
									                    QWidget* parent,
									                    const char* name,
									                    bool modal,
									                    WFlags flags)
    : AffineRegistrationDialogBase (parent, name, modal, flags) {

	this->affineRegistrationTool  = affineRegistrationTool;
	this->initDialog();

}

AffineRegistrationDialogImpl::~AffineRegistrationDialogImpl() {
}

// **************
// public methods
// **************

AffineRegistrationDialogImpl *AffineRegistrationDialogImpl::getInstance (AffineRegistrationTool *affineRegistrationTool) {

	if (instance == 0) {
		instance = new AffineRegistrationDialogImpl (affineRegistrationTool);
	}
	return instance;

}

void AffineRegistrationDialogImpl::destroyInstance() {

	if (instance != 0) {
		instance->close();
		delete instance;
	}
	instance = 0;

}

// ************
// public slots
// ************

void AffineRegistrationDialogImpl::handleRemoveSelected3D() {
	affineRegistrationTool->removeSelectedMarkers();
}

void AffineRegistrationDialogImpl::handleRemoveAll3D() {
	affineRegistrationTool->removeAllMarkers();
}

void AffineRegistrationDialogImpl::handleRegisterObjects() {
	affineRegistrationTool->registerObjects();
}


// ***************
// private methods
// ***************

void AffineRegistrationDialogImpl::initDialog() {	

	
	// get informed whenever the selection changes
	this->connect (CoreTools::getInstance()->getSelectionTool(), SIGNAL (selectionChanged (SurfelInterface::Flag)),
		           this, SLOT (handleSelectionChanged (SurfelInterface::Flag)));
}


// *************
// private slots
// *************
void AffineRegistrationDialogImpl::handleSelectionChanged (SurfelInterface::Flag selectionFlag) {
	if (selectionFlag == SurfelInterface::SELECTED1) {
	}
}

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
