//
// Title:   AffineRegistrationDialogImpl.h
// Created: March 1, 2003
// Authors: Daniel Cotting, Oliver Knoll, Mark Pauly, Matthias Zwicker
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __AFFINEREGISTRATIONDIALOGIMPL_H_
#define __AFFINEREGISTRATIONDIALOGIMPL_H_

#include <qstring.h>
#if QT_VERSION >= 0x030000
# include <qptrlist.h>
# ifndef QList
#  define QList QPtrList
# endif
# ifndef QListIterator
#  define QListIterator QPtrListIterator
# endif
#else
# include <qlist.h>
#endif

#include "../../../../Core/Brush/src/Brush.h"
#include "../../../../Core/MarkerManager/src/MarkerManager.h"
#include "../UI/AffineRegistrationDialog.h"

class AffineRegistrationTool;

/**
 * This class implements a dialog for the affine registration.
 */
class AffineRegistrationDialogImpl : public AffineRegistrationDialogBase {
	
    Q_OBJECT

public:

	/**
	 * This method creates an instance of this <code>AffineRegistrationDialogImpl</code>, if necessary,
	 * and returns it. Only one instance at a time exists (singleton pattern).
	 *
	 * @param AffineRegistrationTool
	 *        a pointer to the <code>AffineRegistrationTool</code>
	 * @return a pointer to an instance of this <code>AffineRegistrationDialogImpl</code>
	 */
	static AffineRegistrationDialogImpl *getInstance (AffineRegistrationTool *affineRegistrationTool);

	/**
	 * Destroys the instance of this <code>AffineRegistrationDialogImpl</code>, if there
	 * is one.
	 */
	static void destroyInstance();

public slots:

	void handleRemoveSelected3D();
	void handleRemoveAll3D();
	void handleRegisterObjects();

private:
	AffineRegistrationTool    *affineRegistrationTool;

	// singleton pattern
	AffineRegistrationDialogImpl (AffineRegistrationTool *affineRegistrationTool,
		                        QWidget *parent = 0,
					            const char *name = 0,
					            bool modal = false,
					            WFlags flags = 0);
protected:  // To suppress warnings...
    virtual ~AffineRegistrationDialogImpl();	

private:
	void initDialog();

private slots:
	void handleSelectionChanged (SurfelInterface::Flag selectionFlag);

};

#endif  // __AFFINEREGISTRATIONDIALOGIMPL_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
